(ftp-download! url f & {:keys [auth resume]})Downloads from the url via FTP and saves it to local as f.
Options:
:auth Username and password for FTP authentication. e.g. {:user "user", :password "password"}
:resume Resume downloading a partially downloaded file if true. You can also specify a resuming byte position as an integer.
Downloads from the url via FTP and saves it to local as f.
Options:
:auth Username and password for FTP authentication.
e.g. {:user "user", :password "password"}
:resume Resume downloading a partially downloaded file if true. You can
also specify a resuming byte position as an integer.(http-download! url f & {:keys [auth resume]})Downloads from the url via HTTP/HTTPS and saves it to local as f.
Options:
:auth Credentials for Basic/Digest/OAuth2 authentications. e.g. {:type :basic, :user "user", :password "password"} {:type :oauth2, :token "access-token"}
:resume Resume downloading a partially downloaded file if true. You can also specify a resuming byte position as an integer.
Downloads from the url via HTTP/HTTPS and saves it to local as f.
Options:
:auth Credentials for Basic/Digest/OAuth2 authentications.
e.g. {:type :basic, :user "user", :password "password"}
{:type :oauth2, :token "access-token"}
:resume Resume downloading a partially downloaded file if true. You can
also specify a resuming byte position as an integer.(s3-download! url f auth & {:keys [resume]})Downloads from the url via S3 protocol and saves it to local as f. The auth format is {:access-key-id "accesskey" :secret-access-key "secretkey"}.
Options:
:resume Resume downloading a partially downloaded file if true. You can also specify a resuming byte position as an integer.
Downloads from the url via S3 protocol and saves it to local as f. The auth
format is {:access-key-id "accesskey" :secret-access-key "secretkey"}.
Options:
:resume Resume downloading a partially downloaded file if true. You can
also specify a resuming byte position as an integer.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |